'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var draw = function draw(width, height, canvasCtx, volume) {
  canvasCtx.clearRect(0, 0, width, height);
  for (var i = 0; i < 5; i++) {
    canvasCtx.fillStyle = (i + 1) * 10 < volume ? 'green' : 'grey';
    var x = width * i / 5;
    var y = height * 0.6 - height * i * 0.15;
    canvasCtx.fillRect(x, y, width / 6, height - y);
    if (i * 10 < volume) {
      canvasCtx.fillRect(x, y, volume % 10 / 10 * (width / 6), height - y);
    }
  }
};

var VolumeMeter = _react2.default.createClass({
  displayName: 'VolumeMeter',
  getVolume: function getVolume() {
    this.analyser.getByteFrequencyData(this.array);
    var length = this.array.length;
    var total = 0;

    for (var i = 0; i < length; i++) {
      total += this.array[i];
    }
    return total / length;
  },
  start: function start() {
    var _this = this;

    var _props = this.props;
    var width = _props.width;
    var height = _props.height;

    var canvasCtx = this.refs.canvas.getContext('2d');

    var drawLoop = function drawLoop() {
      if (_this.analyser.ended) return;
      draw(width, height, canvasCtx, _this.getVolume());
      _this.rafId = window.requestAnimationFrame(drawLoop);
    };

    drawLoop();
  },
  stop: function stop() {
    var _props2 = this.props;
    var width = _props2.width;
    var height = _props2.height;

    var canvasCtx = this.refs.canvas.getContext('2d');
    window.cancelAnimationFrame(this.rafId);
    draw(width, height, canvasCtx, 0);
  },
  componentDidMount: function componentDidMount() {
    var _props3 = this.props;
    var width = _props3.width;
    var height = _props3.height;

    var canvasCtx = this.refs.canvas.getContext('2d');

    draw(width, height, canvasCtx, 0);
  },
  componentWillUpdate: function componentWillUpdate(nextProps) {
    if (!this.props.src && nextProps.src) {
      var audioContext = nextProps.audioContext;
      var src = nextProps.src;

      this.analyser = audioContext.createAnalyser();
      src.connect(this.analyser);
      this.array = new Uint8Array(this.analyser.frequencyBinCount);
    }
  },
  componentDidUpdate: function componentDidUpdate(prevProps) {
    if (this.props.command && this.props.command !== 'none' && prevProps.command !== this.props.command) {
      this[this.props.command]();
    }
  },
  render: function render() {
    var _props4 = this.props;
    var width = _props4.width;
    var height = _props4.height;

    var st = {
      width: width,
      height: height
    };

    return _react2.default.createElement('canvas', {
      ref: 'canvas',
      style: st
    });
  },


  propTypes: {
    command: _react.PropTypes.oneOf(['start', 'stop', 'none']),
    audioContext: _react.PropTypes.object.isRequired,
    src: _react.PropTypes.object,
    width: _react.PropTypes.number.isRequired,
    height: _react.PropTypes.number.isRequired
  }
});

exports.default = VolumeMeter;